# skelevision
An implementation of the Log - Skeleton Visualiser in python.

# Installation
As the package isn't at the moment on pypi, we recommend installing it by cloning this repository, and from the root of it run the following command:
```shell
pip install - e .
```

# Development
Make sure to first install all dependencies via:
```shell
pip install - r requirements.txt
```

# Testing
You can run the following command from the root directory to start the test suit:
```shell
pytest
```
